# enable_gtkdoc: Toggle if gtk-doc files should be rebuilt.
#      0 = no
#      1 = yes
%define enable_gtkdoc 1

# enable_bootstrap: Toggle if bootstrapping package
#      0 = no
#      1 = yes
# N.B. when disabling bootstrap, toggle enable_gtkdoc to 1, otherwise the build
# fails as autoreconf -fi exits with 1
%define enable_bootstrap 0

# enable_tests: Run test suite in build
#      0 = no
#      1 = yes
%define enable_tests 0

%{?_without_gtkdoc: %{expand: %%define enable_gtkdoc 0}}
%{?_without_bootstrap: %{expand: %%define enable_bootstrap 0}}
%{?_without_tests: %{expand: %%define enable_tests 0}}

%{?_with_gtkdoc: %{expand: %%define enable_gtkdoc 1}}
%{?_with_bootstrap: %{expand: %%define enable_bootstrap 1}}
%{?_with_tests: %{expand: %%define enable_tests 1}}


# required version of various libraries
%define req_glib_version		2.27.3
%define req_pango_version		1.20.0
%define req_atk_version			1.29.4
%define req_cairo_version		1.6.0
%define req_gdk_pixbuf_version		2.21.0

%define pkgname			gtk+
%define api_version		2.0
%define binary_version		2.10
%define lib_major		0
%define libname			%mklibname %{pkgname} %{api_version} %{lib_major}
%define libname_x11		%mklibname %{pkgname}-x11- %{api_version} %{lib_major}
%define develname		%mklibname -d %pkgname %api_version

%define gail_major 18
%define gail_libname %mklibname gail %gail_major
%define gaildevelname %mklibname -d gail

%define git_url git://git.gnome.org/gtk+

%define major_url	%(echo %{version}|cut -d. -f1,2)

%define gi_major	2.0
%define girname		%mklibname gtk-gir %gi_major

Summary:	The GIMP ToolKit (GTK+), a library for creating GUIs
Name:		%{pkgname}%{api_version}
Version:	2.24.17
Release:        %mkrel 1
License:	LGPLv2+
Group:		System/Libraries
Source0:	http://download.gnome.org/sources/%{pkgname}/%{major_url}/%{pkgname}-%{version}.tar.xz
# extra IM modules (vietnamese and tamil) -- pablo
#gw TODO, needs to be fixed for 2.21.3
Patch4:		gtk+-2.13.1-extra_im.patch 
# (fc) 2.0.6-8mdk fix infinite loop and crash in file selector when / and $HOME are not readable (bug #90)
Patch5:		gtk+-2.6.9-fileselectorfallback.patch
# (fc) 2.4.0-2mdk use Ia Ora theme by default if available
Patch12:	gtk+-defaulttheme.patch
# (gb) 2.4.4-2mdk handle biarch
Patch13:	gtk+-2.2.4-lib64.patch
# (fc) 2.18.2-2mdv fix nautilus crash (GNOME bug #596977) (pterjan)
Patch15:	gtk+-2.18.1-fixnautiluscrash.patch
# (fc) 2.20.0-2mdv improve tooltip positioning (GNOME bug #599618) (Fedora)
Patch19:	gtk+-2.20.0-tooltip-positioning.patch
# (fc) 2.20.0-2mdv allow window dragging toolbars / menubar (GNOME bug #611313)
Patch20:	gtk+-2.24.7-window-dragging.patch
# (fc) 2.20.0-3mdv allow specifying icon padding for tray icon (GNOME bug #583273) (Fedora)
Patch21:	gtk+-2.20.0-icon-padding.patch
Patch22:	gtk+-2.24.9-link-gmodule.patch
Conflicts:	perl-Gtk2 < 1.113

URL:		http://www.gtk.org
Requires:	common-licenses
BuildRequires:	gettext-devel
BuildRequires:  libglib2.0-devel >= %{req_glib_version}
BuildRequires:	libatk1.0-devel >= %{req_atk_version}
BuildRequires:  cairo-devel >= %{req_cairo_version}
BuildRequires:	pango-devel >= %{req_pango_version}
BuildRequires:  gobject-introspection-devel >= 0.9.5
BuildRequires:	libgdk_pixbuf2.0-devel >= %req_gdk_pixbuf_version
BuildRequires:	libx11-devel
BuildRequires:	libxext-devel
BuildRequires:	libxinerama-devel
BuildRequires:	libxi-devel
BuildRequires:	libxrender-devel
BuildRequires:	libxrandr-devel
BuildRequires:	libxcomposite-devel
BuildRequires:	libxdamage-devel
BuildRequires:	libxfixes-devel
BuildRequires:	libxcursor-devel
BuildRequires:  cups-devel
BuildRequires:  fam-devel
%if %enable_tests
BuildRequires:  x11-server-xvfb
%endif
%if %enable_gtkdoc
BuildRequires: gtk-doc >= 0.9 
BuildRequires: sgml-tools
BuildRequires: texinfo
%endif
# gw tests will fail without this
BuildRequires: fonts-ttf-dejavu
# so that the demos don't fail to build
BuildRequires: shared-mime-info
%if !%{enable_bootstrap}
Requires: xdg-user-dirs-gtk
Suggests: oxygen-gtk
%endif
Requires: %{libname} = %{version}
Provides:	%{pkgname}2 = %{version}-%{release}
Obsoletes:	%{pkgname}2
Provides:	gail = %version-%release
Obsoletes:	gail

%description
The gtk+ package contains the GIMP ToolKit (GTK+), a library for creating
graphical user interfaces for the X Window System.  GTK+ was originally
written for the GIMP (GNU Image Manipulation Program) image processing
program, but is now used by several other programs as well.  

If you are planning on using the GIMP or another program that uses GTK+,
you'll need to have the gtk+ package installed.


%post
if [ -d %{_datadir}/icons ]; then
 for i in `/bin/ls %{_datadir}/icons` ; do
  [ -d "%{_datadir}/icons/$i" -a -e "%{_datadir}/icons/$i/icon-theme.cache" -a -e "%{_datadir}/icons/$i/index.theme" ] && gtk-update-icon-cache --force --quiet %{_datadir}/icons/$i
 done
 exit 0
fi

%files -f gtk20.lang
%doc README
%{_bindir}/gtk-query-immodules-%{api_version}
%{_bindir}/gtk-update-icon-cache
%{_datadir}/themes
%dir %{_sysconfdir}/gtk-%{api_version}
%config(noreplace) %{_sysconfdir}/gtk-%{api_version}/im-multipress.conf

#--------------------------------------------------------------------

%package -n %{libname}
Summary: %{summary}
Group:	 %{group}
Obsoletes:	lib%{pkgname}2
Provides:	lib%{pkgname}2 = %{version}-%{release}
Provides:	lib%{name} = %{version}-%{release}
Provides:   gtk2 = %{version}-%{release}
Requires:   libglib2.0 >= %{req_glib_version}
Requires:   libpango1.0 >= %{req_pango_version}
Requires:   glib2.0-common
Requires(post): 	%{libname_x11} = %{version}
%if !%{enable_bootstrap}
Suggests: %{_lib}oxygen-gtk
%endif

%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with gtk+.

%post -n %{libname}
if [ "$1" = "2" ]; then
  if [ -f %{_sysconfdir}/gtk-%{api_version}/gtk.immodules ]; then
    rm -f %{_sysconfdir}/gtk-%{api_version}/gtk.immodules
  fi
fi

%{_libdir}/gtk-%{api_version}/bin/gtk-query-immodules-%{api_version} > %{_sysconfdir}/gtk-%{api_version}/gtk.immodules.%{_lib}

%files -n %{libname}
%doc README
%ghost %verify (not md5 mtime size) %config(noreplace) %{_sysconfdir}/gtk-%{api_version}/gtk.immodules.%{_lib}
%dir %{_libdir}/gtk-%{api_version}
%dir %{_libdir}/gtk-%{api_version}/bin
%{_libdir}/gtk-%{api_version}/bin/gtk-query-immodules-%{api_version}
%dir %{_libdir}/gtk-%{api_version}/modules
%dir %{_libdir}/gtk-%{api_version}/%{binary_version}.*
%dir %{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-am-et.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-cedilla.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-cyrillic-translit.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-inuktitut.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-ipa.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-multipress.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-thai.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-ti-er.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-ti-et.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-viqr.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-xim.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-tamilvp-tsc.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-tamilvp-uni.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-telex.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/immodules/im-vni.so
%dir %{_libdir}/gtk-%{api_version}/%{binary_version}.*/engines
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/engines/*.so
%{_libdir}/gtk-%{api_version}/%{binary_version}.*/printbackends/*.so

#--------------------------------------------------------------------

%package -n %{develname}
Summary:	Development files for GTK+ (GIMP ToolKit) applications
Group:		Development/GNOME and GTK+
Obsoletes:  %{libname_x11}-devel
Provides:   %{libname_x11}-devel = %{version}-%{release}
Provides:   gtk2-devel = %{version}-%{release}
Obsoletes:	%{pkgname}2-devel
Obsoletes:  lib%{pkgname}2-devel
Obsoletes:  %mklibname -d %{pkgname} 2.0 0
Provides:	%{pkgname}2-devel = %{version}-%{release}
Provides:	lib%{pkgname}2-devel = %{version}-%{release}
Provides:	lib%{pkgname}%{api_version}-devel = %{version}-%{release}
Provides:	%{libname}-devel = %{version}-%{release}
Provides:	lib%{pkgname}-x11-%{api_version}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}
Requires:	%{libname_x11} = %{version}
Requires:	libgdk_pixbuf2.0-devel >= %req_gdk_pixbuf_version
Requires:	libatk1.0-devel >= %{req_atk_version}
Requires:	libpango1.0-devel >= %{req_pango_version}


%description -n %{develname}
The libgtk+-devel package contains the static libraries and header files
needed for developing GTK+ (GIMP ToolKit) applications. The libgtk+-devel
package contains GDK (the General Drawing Kit, which simplifies the interface
for writing GTK+ widgets and using GTK+ widgets in applications), and GTK+
(the widget set).

%files -n %develname
%doc docs/*.txt AUTHORS ChangeLog NEWS README*
%doc %{_datadir}/gtk-doc/html/gdk2
%doc %{_datadir}/gtk-doc/html/gtk2
%{_bindir}/gtk-demo
%_bindir/gtk-builder-convert
%{_datadir}/aclocal/*
%{_datadir}/gtk-%{api_version}
%{_includedir}/gtk-unix-print-%{api_version}/
%{_includedir}/gtk-%{api_version}/gdk
%{_includedir}/gtk-%{api_version}/gtk
%{_libdir}/gtk-%{api_version}/include
%{_libdir}/pkgconfig/gdk-%{api_version}.pc
%{_libdir}/pkgconfig/gtk+-%{api_version}.pc
%{_libdir}/pkgconfig/gtk+-unix-print-%{api_version}.pc
%{_libdir}/*x11*.so
%_datadir/gir-1.0/Gdk-2.0.gir
%_datadir/gir-1.0/GdkX11-2.0.gir
%_datadir/gir-1.0/Gtk-2.0.gir
%{_libdir}/pkgconfig/*x11*

#--------------------------------------------------------------------

%package -n %{libname_x11}
Summary:	X11 backend of The GIMP ToolKit (GTK+)
Group:		System/Libraries
Provides:	lib%{pkgname}-x11-%{api_version} = %{version}-%{release}
Provides:	%{name}-backend = %{version}-%{release}
Requires: 	%{libname} = %{version}
Requires:	%{name} >= %{version}-%{release}
Requires:	libatk1.0 >= %{req_atk_version}
Requires:	%{mklibname xi 6} >= 1.4.5
Requires:	%{mklibname x11_ 6} >= 1.4.99.1
Conflicts: gir-repository < 0.6.5-4

%description -n %{libname_x11}
This package contains the X11 version of library needed to run
programs dynamically linked with gtk+.

%files -n %{libname_x11}
%{_libdir}/libgdk-x11-%{api_version}.so.%{lib_major}
%{_libdir}/libgdk-x11-%{api_version}.so.%{lib_major}.*
%{_libdir}/libgtk-x11-%{api_version}.so.%{lib_major}
%{_libdir}/libgtk-x11-%{api_version}.so.%{lib_major}.*

#--------------------------------------------------------------------

%package -n %{gail_libname}
Summary:	GNOME Accessibility Implementation Library
Group:		System/Libraries
Provides:	libgail = %{version}-%{release}

%description -n %{gail_libname}
Gail is the GNOME Accessibility Implementation Library

%files -n %gail_libname
%{_libdir}/libgailutil.so.%{gail_major}*
%{_libdir}/gtk-2.0/modules/libferret.so
%{_libdir}/gtk-2.0/modules/libgail.so

#--------------------------------------------------------------------

%package -n %gaildevelname
Summary:	Static libraries, include files for GAIL
Group:		Development/GNOME and GTK+
Provides:	gail-devel = %{version}-%{release}
Provides:	libgail-devel = %{version}-%{release}
Requires:	%{gail_libname} = %{version}
Conflicts:	%{_lib}gail17-devel
Obsoletes: %mklibname -d gail 18

%description -n %gaildevelname
Gail is the GNOME Accessibility Implementation Library

%files -n %gaildevelname
%{_datadir}/gtk-doc/html/gail-libgail-util
%{_libdir}/libgailutil.so
%{_includedir}/gail-1.0
%{_libdir}/pkgconfig/gail.pc

#--------------------------------------------------------------------

%package -n %{girname}
Summary:        GObject Introspection interface description for %name
Group:          System/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libname_x11} = %{version}-%{release}
Conflicts:	%{mklibname %{name}-gir 2.0} < 2.24.5-5
Conflicts:	%{mklibname %{pkgname}-x11- 2.0 0} < 2.24.5-3

%description -n %{girname}
GObject Introspection interface description for %name.

%files -n %{girname}
%_libdir/girepository-1.0/Gdk-%{gi_major}.typelib
%_libdir/girepository-1.0/GdkX11-%{gi_major}.typelib
%_libdir/girepository-1.0/Gtk-%{gi_major}.typelib

#--------------------------------------------------------------------

%prep
%setup -n %{pkgname}-%{version} -q
%patch4 -p1 -b .extra_im
%patch5 -p1 -b .fileselectorfallback
%patch12 -p1 -b .defaulttheme
%if !%{enable_bootstrap}
#gw disabled for bootstrapping
%patch13 -p1 -b .lib64
%endif
#patch15 -p1 -b .fixnautiluscrash
#%patch19 -p1 -b .tooltip-positioning
%patch20 -p1 -b .window-dragging
%patch21 -p1 -b .icon-padding
%patch22 -p0 -b .link-gmodule

%build
# generate build scripts with our autotools
mkdir -p m4
autoreconf -fi

%ifarch ppc64
export CFLAGS="$RPM_OPT_FLAGS -mminimal-toc"
%endif

# Build X11 backend
#[ -d X11-build ] || mkdir X11-build
#cd X11-build

# fix crash in nautilus (GNOME bug #596977)
export CFLAGS=`echo $RPM_OPT_FLAGS | sed -e 's/-fomit-frame-pointer//g'`

#CONFIGURE_TOP=.. 
export CPPFLAGS="-DGTK_COMPILATION"
#	--with-included-immodules=yes \
%configure2_5x --enable-xinerama \
	--with-xinput=xfree \
%if !%enable_gtkdoc
	--enable-gtk-doc=no
%endif

%make

%check
%if %enable_tests
#cd X11-build
XDISPLAY=$(i=1; while [ -f /tmp/.X$i-lock ]; do i=$(($i+1)); done; echo $i)
%{_bindir}/Xvfb :$XDISPLAY &
export DISPLAY=:$XDISPLAY
make check
kill $(cat /tmp/.X$XDISPLAY-lock) ||:
#cd ..
%endif

%install
rm -rf $RPM_BUILD_ROOT

#cd X11-build
%makeinstall_std mandir=%{_mandir} RUN_QUERY_IMMODULES_TEST=false RUN_QUERY_LOADER_TEST=false


#cd ..

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/gtk-%{api_version}
touch $RPM_BUILD_ROOT%{_sysconfdir}/gtk-%{api_version}/gtk.immodules.%{_lib}
mkdir -p $RPM_BUILD_ROOT%{_libdir}/gtk-%{api_version}/modules

# handle biarch packages
progs="gtk-query-immodules-%{api_version}"
mkdir -p $RPM_BUILD_ROOT%{_libdir}/gtk-%{api_version}/bin
for f in $progs; do
  mv -f $RPM_BUILD_ROOT%{_bindir}/$f $RPM_BUILD_ROOT%{_libdir}/gtk-%{api_version}/bin/
  cat > $RPM_BUILD_ROOT%{_bindir}/$f << EOF
#!/bin/sh
lib=%{_lib}
case ":\$1:" in
:lib*:) lib="\$1"; shift 1;;
esac
exec %{_prefix}/\$lib/gtk-%{api_version}/bin/$f \${1+"\$@"}
EOF
  chmod +x $RPM_BUILD_ROOT%{_bindir}/$f
done

%{find_lang} gtk20
%find_lang gtk20-properties
cat gtk20-properties.lang >> gtk20.lang

#remove not packaged files
find %{buildroot} -name *.la | xargs rm


%changelog

* Sun Apr 07 2013 wally <wally> 2.24.17-1.mga3
+ Revision: 408832
- new version 2.24.17

  + tv <tv>
    - do not package useless gtk+-0.99 NEWS

* Thu Feb 21 2013 wally <wally> 2.24.16-1.mga3
+ Revision: 399645
- new version 2.24.16
- drop unneeded automake 1.13 patch

* Sat Jan 12 2013 umeabot <umeabot> 2.24.14-2.mga3
+ Revision: 352800
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 cjw <cjw> 2.24.14-1.mga3
+ Revision: 338849
- fix filelist for changed gtk-doc dir names
- fix automake 1.13 patch to remove AM_PROG_CC_STDC

  + dmorgan <dmorgan>
    - Fix build against new libtool

  + ovitters <ovitters>
    - new version 2.24.14

* Wed Oct 31 2012 fwang <fwang> 2.24.13-2.mga3
+ Revision: 311704
- cleanup spec
- lock libmajor
- suggests oxygen instead of ia_ora
- drop last ia_ora reference

* Sun Sep 23 2012 ovitters <ovitters> 2.24.13-1.mga3
+ Revision: 296937
- new version 2.24.13

* Wed Sep 05 2012 fwang <fwang> 2.24.12-1.mga3
+ Revision: 288379
- tooltip related feature accepted by upstream in anoth bugreport (gnome bug#683070)
- new version 2.24.12

* Sun Jul 15 2012 ovitters <ovitters> 2.24.11-1.mga3
+ Revision: 271124
- new version 2.24.11

* Thu Apr 05 2012 tv <tv> 2.24.10-4.mga2
+ Revision: 228754
- require recent enough versions of libx11 & libxi so that live upgrade works
  after priority upgrade (mga#5168)
  (priority updates upgrades perl, thus perl-Gtk2, thus gtk+-2.x)

  + fwang <fwang>
    - drop unused part

* Fri Feb 10 2012 tv <tv> 2.24.10-3.mga2
+ Revision: 206893
- suggests oxygen them again now that metacity crash is fixed (mga#4408)
  (replaced the Requires tag by a Suggests one btw)

* Thu Feb 09 2012 tv <tv> 2.24.10-2.mga2
+ Revision: 206608
- do not pull oxygen them (too buggy)

* Mon Feb 06 2012 fwang <fwang> 2.24.10-1.mga2
+ Revision: 205457
- new version 2.24.10

* Wed Jan 25 2012 fwang <fwang> 2.24.9-1.mga2
+ Revision: 200717
- fix linkage against gmodule
- new version 2.24.9

  + tv <tv>
    - requires glib2.0-common instead of in basesystem

* Sun Dec 04 2011 obgr_seneca <obgr_seneca> 2.24.8-3.mga2
+ Revision: 176163
- fixed iconview bug causing lxappearance crashes
- patch fron upstream

* Sun Nov 13 2011 dmorgan <dmorgan> 2.24.8-2.mga2
+ Revision: 167299
- Move suggests as requires as it does not work well w/o

* Fri Nov 11 2011 wally <wally> 2.24.8-1.mga2
+ Revision: 166689
- new version 2.24.8
- rediff P12

* Mon Oct 24 2011 fwang <fwang> 2.24.7-2.mga2
+ Revision: 157593
- bump rel for rebuilding

* Sun Oct 23 2011 wally <wally> 2.24.7-1.mga2
+ Revision: 157493
- new version 2.24.7
- rediff P20

* Sat Sep 10 2011 fwang <fwang> 2.24.6-2.mga2
+ Revision: 142171
- rebuild for new libpng

* Wed Aug 31 2011 fwang <fwang> 2.24.6-1.mga2
+ Revision: 137179
- new version 2.24.6

* Mon Jul 11 2011 wally <wally> 2.24.5-6.mga2
+ Revision: 122408
- fix gir package requires (require libs)

* Sat Jul 09 2011 wally <wally> 2.24.5-5.mga2
+ Revision: 121215
- fix gir package name

  + dmorgan <dmorgan>
    - Remove wrong conflicts/requires

* Thu Jul 07 2011 dmorgan <dmorgan> 2.24.5-4.mga2
+ Revision: 119810
- Fix file list
- Split gir files outside lib package
- Sync spec file with gtk3

* Thu Jul 07 2011 fwang <fwang> 2.24.5-3.mga2
+ Revision: 119570
- rebuild for typelib rpm provides

* Tue Jul 05 2011 dmorgan <dmorgan> 2.24.5-2.mga2
+ Revision: 118944
- Fix default theme ( for coherency with gnome3 theme)

* Mon Jun 20 2011 fwang <fwang> 2.24.5-1.mga2
+ Revision: 110239
- new version 2.24.5

* Mon Jun 13 2011 ahmad <ahmad> 2.24.4-3.mga2
+ Revision: 105586
- Ship libgailutil.la for now, some builds (e.g. claws-mail-plugins) fail without it

* Thu Jun 09 2011 dmorgan <dmorgan> 2.24.4-2.mga2
+ Revision: 102524
- Do not package libgailutil.la

* Thu Apr 14 2011 tv <tv> 2.24.4-1.mga1
+ Revision: 85366
- new release

* Sun Mar 27 2011 ahmad <ahmad> 2.24.3-2.mga1
+ Revision: 77894
- add BR shared-mime-info so that the demos don't fail to build
- update to 2.24.3
- bump req_glib_version
- replace X11-devel with the required -devel packages
- move the libatk1.0 requires to the x11 subpackage (fwang)

* Mon Feb 14 2011 dmorgan <dmorgan> 2.22.1-2.mga1
+ Revision: 51705
- Fix file list
- Disable bootstrap
- Remove old conflicts

  + ahmad <ahmad>
    - add a comment about the need to toggle enable_gtkdoc to 1 when disabling the
      bootstrap, otherwise the build fails as autoreconf -fi exits with 1
    - when disabling the bootstrap, re-enable gtkdoc so that autoreconf -fi doesn't
      exit with 1

* Wed Jan 12 2011 dmorgan <dmorgan> 2.22.1-1.mga1
+ Revision: 7731
- Fix file list
- Disable autoreconf like told in comment
- Disable patch13 like told in comment
- imported package gtk+2.0

  + ahmad <ahmad>
    - drop old/unneeded scriptlets, and old conflicts
    - imported package gtk+2.0


* Mon Nov 15 2010 Götz Waschk <waschk@mandriva.org> 2.22.1-1mdv2011.0
+ Revision: 597833
- update to new version 2.22.1

* Fri Sep 24 2010 Funda Wang <fwang@mandriva.org> 2.22.0-1mdv2011.0
+ Revision: 580827
- new version 2.22.0

* Tue Sep 14 2010 Götz Waschk <waschk@mandriva.org> 2.21.8-1mdv2011.0
+ Revision: 578284
- new version
- drop patches 0,1,2

* Sun Sep 12 2010 Götz Waschk <waschk@mandriva.org> 2.21.7-2mdv2011.0
+ Revision: 577661
- add patches 0,1,2 to support the new gobject-introspection

* Mon Aug 30 2010 Götz Waschk <waschk@mandriva.org> 2.21.7-1mdv2011.0
+ Revision: 574525
- update to new version 2.21.7

* Tue Aug 17 2010 Götz Waschk <waschk@mandriva.org> 2.21.6-1mdv2011.0
+ Revision: 570882
- new version
- update file list

* Fri Jul 30 2010 Funda Wang <fwang@mandriva.org> 2.21.5-2mdv2011.0
+ Revision: 563282
- rebuild for patch13 and gtk-doc

* Thu Jul 29 2010 Götz Waschk <waschk@mandriva.org> 2.21.5-1mdv2011.0
+ Revision: 563175
- fix bootstrapping
- bootstrap build without gtk-doc
- bump gdk_pixbuf dep
- new version
- spec file cleanup
- bump glib dep
- remove gdk_pixbuf
- new devel package name
- rediff patch 18
- disable patch 19
- drop patch 22
- fix immodules cache file location

* Mon May 03 2010 Götz Waschk <waschk@mandriva.org> 2.20.1-1mdv2010.1
+ Revision: 541700
- new version
- drop patches 16,17

* Thu Apr 29 2010 Christophe Fergeau <cfergeau@mandriva.com> 2.20.0-5mdv2010.1
+ Revision: 540855
- rebuild so that shared libraries are properly stripped again
- rebuild so that shared libraries are properly stripped again

* Mon Apr 26 2010 Frederic Crozat <fcrozat@mandriva.com> 2.20.0-3mdv2010.1
+ Revision: 539036
- Patch21 (Fedora): allow specifying icon padding for tray icon (GNOME bug #583273)
- Patch22 (GIT): use proper screen for getshape (GNOME bug #615853)

* Wed Apr 14 2010 Frederic Crozat <fcrozat@mandriva.com> 2.20.0-2mdv2010.1
+ Revision: 534848
- Patch16 (GIT): fix support for tracker 0.8
- Patch17 (GIT): delay search startup
- Patch18 (Fedora): improve tooltip appareance (GNOME bug #599617)
- Patch19 (Fedora): improve tooltip positioning (GNOME bug #599618)
- Patch20 (Fedora): allow window dragging toolbars / menubar (GNOME bug #611313)

* Tue Mar 23 2010 Götz Waschk <waschk@mandriva.org> 2.20.0-1mdv2010.1
+ Revision: 526805
- update to new version 2.20.0

* Tue Mar 09 2010 Götz Waschk <waschk@mandriva.org> 2.19.7-1mdv2010.1
+ Revision: 517217
- update to new version 2.19.7

* Tue Feb 23 2010 Götz Waschk <waschk@mandriva.org> 2.19.6-1mdv2010.1
+ Revision: 510461
- update to new version 2.19.6

* Wed Feb 10 2010 Götz Waschk <waschk@mandriva.org> 2.19.5-1mdv2010.1
+ Revision: 503767
- update to new version 2.19.5

* Thu Jan 28 2010 Frederic Crozat <fcrozat@mandriva.com> 2.19.4-2mdv2010.1
+ Revision: 497637
- cleanup build

* Tue Jan 26 2010 Götz Waschk <waschk@mandriva.org> 2.19.4-1mdv2010.1
+ Revision: 496515
- new version
- drop patches 16,17

* Wed Jan 20 2010 Götz Waschk <waschk@mandriva.org> 2.19.3-3mdv2010.1
+ Revision: 494035
- disable parallel make
- patch for b.g.o #607508 (cannot drag window on the pager)

* Mon Jan 18 2010 Pascal Terjan <pterjan@mandriva.org> 2.19.3-2mdv2010.1
+ Revision: 492997
- Add upstream patch fixing xchat and pidgin unhilight of active channel

* Mon Jan 11 2010 Götz Waschk <waschk@mandriva.org> 2.19.3-1mdv2010.1
+ Revision: 489869
- new version
- drop patch 16

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 2.19.2-4mdv2010.1
+ Revision: 488762
- rebuilt against libjpeg v8

* Fri Dec 25 2009 Götz Waschk <waschk@mandriva.org> 2.19.2-3mdv2010.1
+ Revision: 482173
- add missing typelib

* Wed Dec 23 2009 Christophe Fergeau <cfergeau@mandriva.com> 2.19.2-2mdv2010.1
+ Revision: 481673
- add upstream patch to fix a crash in sylpheed

* Tue Dec 22 2009 Götz Waschk <waschk@mandriva.org> 2.19.2-1mdv2010.1
+ Revision: 481237
- new version
- update deps
- add introspection support

* Wed Dec 09 2009 Götz Waschk <waschk@mandriva.org> 2.19.1-1mdv2010.1
+ Revision: 475519
- new version
- bump atk dep

* Tue Dec 08 2009 Götz Waschk <waschk@mandriva.org> 2.18.5-1mdv2010.1
+ Revision: 474908
- update to new version 2.18.5

* Tue Dec 01 2009 Götz Waschk <waschk@mandriva.org> 2.18.4-1mdv2010.1
+ Revision: 472199
- new version
- fix build
- drop patches 14, 16, 17, 18

* Thu Oct 29 2009 Frederic Crozat <fcrozat@mandriva.com> 2.18.3-3mdv2010.0
+ Revision: 459955
-Patch16 (GIT): fix toolbutton assert (GNOME bug #299446)
-Patch17 (GIT): fix iconview hang (GNOME bug #581150)
-Patch18 (GIT): fix symbolic color parsing

* Fri Oct 23 2009 Frederic Crozat <fcrozat@mandriva.com> 2.18.3-2mdv2010.0
+ Revision: 459071
- Change default themes for One / Free / Powerpack

* Tue Oct 20 2009 Götz Waschk <waschk@mandriva.org> 2.18.3-1mdv2010.0
+ Revision: 458335
- update to new version 2.18.3

* Wed Oct 07 2009 Thierry Vignaud <tv@mandriva.org> 2.18.2-4mdv2010.0
+ Revision: 455480
- do not package huge NEWS 3 times (one time in devel package is enough)

* Tue Oct 06 2009 Frederic Crozat <fcrozat@mandriva.com> 2.18.2-3mdv2010.0
+ Revision: 454646
- Disable patch15 for now, not stable enough

* Tue Oct 06 2009 Frederic Crozat <fcrozat@mandriva.com> 2.18.2-2mdv2010.0
+ Revision: 454628
- Patch15 (pterjan): fix crash in nautilus (GNOME bug #596977)

* Tue Oct 06 2009 Götz Waschk <waschk@mandriva.org> 2.18.2-1mdv2010.0
+ Revision: 454343
- update to new version 2.18.2

* Thu Oct 01 2009 Frederic Crozat <fcrozat@mandriva.com> 2.18.1-2mdv2010.0
+ Revision: 452235
- Workaround crash in nautilus / moovida by remove -fomit-frame-pointer from CFLAGS

* Thu Oct 01 2009 Götz Waschk <waschk@mandriva.org> 2.18.1-1mdv2010.0
+ Revision: 451983
- update to new version 2.18.1

* Wed Sep 23 2009 Götz Waschk <waschk@mandriva.org> 2.18.0-1mdv2010.0
+ Revision: 447655
- new version
- drop patches 0,1

* Wed Sep 16 2009 Götz Waschk <waschk@mandriva.org> 2.17.11-3mdv2010.0
+ Revision: 443447
- install translations (bug #53681)

* Fri Sep 11 2009 Götz Waschk <waschk@mandriva.org> 2.17.11-2mdv2010.0
+ Revision: 437897
- fix window refresh in padre (bug #52802)

* Sat Sep 05 2009 Götz Waschk <waschk@mandriva.org> 2.17.11-1mdv2010.0
+ Revision: 432062
- new version
- fix build

* Tue Sep 01 2009 Götz Waschk <waschk@mandriva.org> 2.17.10-1mdv2010.0
+ Revision: 423656
- new version
- drop patches 15,16

* Tue Sep 01 2009 Frederic Crozat <fcrozat@mandriva.com> 2.17.9-3mdv2010.0
+ Revision: 423609
- Patch16 (GIT): fix crash in acroread (GNOME bug #59324) (Mdv bug #53175)

* Thu Aug 27 2009 Pascal Terjan <pterjan@mandriva.org> 2.17.9-2mdv2010.0
+ Revision: 421691
- Fix changing icons in GtkEntry

  + Frederic Crozat <fcrozat@mandriva.com>
    - Fix dependencies (Mdv bug #53224)

* Tue Aug 25 2009 Götz Waschk <waschk@mandriva.org> 2.17.9-1mdv2010.0
+ Revision: 420760
- update to new version 2.17.9

* Wed Aug 19 2009 Götz Waschk <waschk@mandriva.org> 2.17.8-2mdv2010.0
+ Revision: 417940
- fix blurry jpeg display with libjpeg 7 (bug #52960)

* Tue Aug 18 2009 Götz Waschk <waschk@mandriva.org> 2.17.8-1mdv2010.0
+ Revision: 417529
- new version
- drop patch 14

* Sun Aug 16 2009 Colin Guthrie <cguthrie@mandriva.org> 2.17.7-3mdv2010.0
+ Revision: 417094
- Add upstream fix for drag and drop offset weirdness in FF/TB (gbz#588437)

* Sat Aug 15 2009 Oden Eriksson <oeriksson@mandriva.com> 2.17.7-2mdv2010.0
+ Revision: 416616
- rebuilt against libjpeg v7

* Tue Aug 11 2009 Götz Waschk <waschk@mandriva.org> 2.17.7-1mdv2010.0
+ Revision: 415174
- new version
- drop patches 14,15

* Tue Aug 11 2009 Frederic Crozat <fcrozat@mandriva.com> 2.17.6-3mdv2010.0
+ Revision: 415106
- Patch15: fix mouse cursor on gdm (GNOME bug #589844)

* Tue Aug 11 2009 Pascal Terjan <pterjan@mandriva.org> 2.17.6-2mdv2010.0
+ Revision: 414971
- Add a way to disable folder creation in file choser (applied upstream)

* Sat Jul 25 2009 Götz Waschk <waschk@mandriva.org> 2.17.6-1mdv2010.0
+ Revision: 399671
- new version
- drop patches 14,15

* Fri Jul 24 2009 Frederic Crozat <fcrozat@mandriva.com> 2.17.5-3mdv2010.0
+ Revision: 399476
- Patch15 (GIT): more csw fixes

* Thu Jul 23 2009 Frederic Crozat <fcrozat@mandriva.com> 2.17.5-2mdv2010.0
+ Revision: 398984
- Patch14 (GIT): various bugfixes, mostly csw related
- Bump glib dependency (Mdv bug #52107)

* Sat Jul 18 2009 Götz Waschk <waschk@mandriva.org> 2.17.5-1mdv2010.0
+ Revision: 396993
- update to new version 2.17.5

* Sat Jul 11 2009 Götz Waschk <waschk@mandriva.org> 2.17.4-1mdv2010.0
+ Revision: 394713
- update to new version 2.17.4

* Tue Jul 07 2009 Götz Waschk <waschk@mandriva.org> 2.17.3-1mdv2010.0
+ Revision: 393144
- update to new version 2.17.3

* Tue Jun 16 2009 Götz Waschk <waschk@mandriva.org> 2.17.2-1mdv2010.0
+ Revision: 386271
- new version

* Sat May 30 2009 Götz Waschk <waschk@mandriva.org> 2.17.1-1mdv2010.0
+ Revision: 381485
- new version
- drop patch 20

* Mon May 11 2009 Götz Waschk <waschk@mandriva.org> 2.17.0-1mdv2010.0
+ Revision: 374172
- new version
- update file list

* Mon Apr 20 2009 Frederic Crozat <fcrozat@mandriva.com> 2.16.1-4mdv2009.1
+ Revision: 368421
- Fix typo in Arctic theme name in patch 12

* Thu Apr 16 2009 Frederic Crozat <fcrozat@mandriva.com> 2.16.1-3mdv2009.1
+ Revision: 367770
- Update patch12 to disable sound events by default (Mdv bug #48319)

* Wed Apr 15 2009 Frederic Crozat <fcrozat@mandriva.com> 2.16.1-2mdv2009.1
+ Revision: 367435
- Fix default themes for One and Powerpack

* Tue Apr 14 2009 Götz Waschk <waschk@mandriva.org> 2.16.1-1mdv2009.1
+ Revision: 367001
- update to new version 2.16.1

* Wed Apr 01 2009 Frederic Crozat <fcrozat@mandriva.com> 2.16.0-2mdv2009.1
+ Revision: 363309
- Remove patch22, no longer needed
- Update patch12 with theme colors changed for Mdv 2009.1

* Fri Mar 13 2009 Götz Waschk <waschk@mandriva.org> 2.16.0-1mdv2009.1
+ Revision: 354612
- new version
- drop patch 23

* Fri Mar 13 2009 Götz Waschk <waschk@mandriva.org> 2.15.5-2mdv2009.1
+ Revision: 354582
- fix regression in GtkCompoBoxEntry (upstream bug #574059)

* Mon Mar 02 2009 Götz Waschk <waschk@mandriva.org> 2.15.5-1mdv2009.1
+ Revision: 347527
- new version
- drop patch 21

* Fri Feb 27 2009 Frederic Crozat <fcrozat@mandriva.com> 2.15.4-3mdv2009.1
+ Revision: 345639
- Don't try to rebuild cache if there is no index.theme (Mdv bug #47981)

* Thu Feb 19 2009 Frederic Crozat <fcrozat@mandriva.com> 2.15.4-2mdv2009.1
+ Revision: 342913
- Patch21 (SVN): fix randr support on old xrandr driver
- Patch22 (SVN): fix for driver not supporting randr < 1.2 (Mdv bug #47996)

* Wed Feb 18 2009 Götz Waschk <waschk@mandriva.org> 2.15.4-1mdv2009.1
+ Revision: 342273
- new version
- bump glib dep

* Tue Feb 03 2009 Götz Waschk <waschk@mandriva.org> 2.15.3-2mdv2009.1
+ Revision: 336788
- drop patch 21

* Tue Feb 03 2009 Götz Waschk <waschk@mandriva.org> 2.15.3-1mdv2009.1
+ Revision: 336741
- update to new version 2.15.3

  + Frederic Crozat <fcrozat@mandriva.com>
    - Update patch12 to change sound theme too
    - Don't start Xvfb if tests are disabled
    - Add git mirror url to specfile

* Tue Jan 27 2009 Frederic Crozat <fcrozat@mandriva.com> 2.15.2-2mdv2009.1
+ Revision: 334182
- Patch21: fix crash in gtk button

* Tue Jan 27 2009 Götz Waschk <waschk@mandriva.org> 2.15.2-1mdv2009.1
+ Revision: 334033
- update to new version 2.15.2

* Sat Jan 24 2009 Götz Waschk <waschk@mandriva.org> 2.15.1-1mdv2009.1
+ Revision: 333234
- new version
- drop patch 21

* Thu Jan 22 2009 Frederic Crozat <fcrozat@mandriva.com> 2.15.0-2mdv2009.1
+ Revision: 332462
- Patch21 (SVN): fix gtk entry loop (GNOME bug #568552)

* Fri Jan 02 2009 Götz Waschk <waschk@mandriva.org> 2.15.0-1mdv2009.1
+ Revision: 323264
- new version
- new source URL

* Thu Dec 18 2008 Götz Waschk <waschk@mandriva.org> 2.14.6-1mdv2009.1
+ Revision: 315780
- new version
- fix source URL

* Mon Nov 24 2008 Götz Waschk <waschk@mandriva.org> 2.14.5-1mdv2009.1
+ Revision: 306475
- new version
- fix build

* Fri Nov 07 2008 Götz Waschk <waschk@mandriva.org> 2.14.4-2mdv2009.1
+ Revision: 300653
- rebuild for new libxcb

* Fri Oct 17 2008 Götz Waschk <waschk@mandriva.org> 2.14.4-1mdv2009.1
+ Revision: 294690
- new version
- drop patch 21

* Tue Sep 30 2008 Frederic Crozat <fcrozat@mandriva.com> 2.14.3-2mdv2009.0
+ Revision: 290227
- Patch21 (SVN): various bug fixes from SVN

* Wed Sep 24 2008 Götz Waschk <waschk@mandriva.org> 2.14.3-1mdv2009.0
+ Revision: 287716
- new version
- drop patch 21

* Sat Sep 20 2008 Frederic Crozat <fcrozat@mandriva.com> 2.14.2-2mdv2009.0
+ Revision: 286072
- Patch21: fix i18n init in fileselector (GNOME bug #553000)

* Thu Sep 18 2008 Götz Waschk <waschk@mandriva.org> 2.14.2-1mdv2009.0
+ Revision: 285596
- new version
- drop patch 21

* Wed Sep 10 2008 Frederic Crozat <fcrozat@mandriva.com> 2.14.1-2mdv2009.0
+ Revision: 283491
- Patch21 (SVN) : drop RandR 1.2 calls, it is too slow and cause flickering

* Fri Sep 05 2008 Götz Waschk <waschk@mandriva.org> 2.14.1-1mdv2009.0
+ Revision: 281046
- new version
- drop patch 21

* Tue Aug 26 2008 Frederic Crozat <fcrozat@mandriva.com> 2.13.7-2mdv2009.0
+ Revision: 276112
- Remove patch22, we won't backport gtk 2.14
- Patch21: fix window reparenting regression (Mdv bug #42487) (GNOME bug #548993)
- Update patch12 to use always use Ia Ora Smooth

* Tue Aug 19 2008 Götz Waschk <waschk@mandriva.org> 2.13.7-1mdv2009.0
+ Revision: 273715
- new version
- drop patches 23,24

* Mon Aug 18 2008 Frederic Crozat <fcrozat@mandriva.com> 2.13.6-3mdv2009.0
+ Revision: 273281
- Patch24 (SVN): fix keyboard navigation in menu (GNOME bug #547027, Mdv bug #42914)

* Tue Aug 12 2008 Frederic Crozat <fcrozat@mandriva.com> 2.13.6-2mdv2009.0
+ Revision: 271190
- Patch23 (SVN): fix misrendering in evolution composer (GNOME bug #546754)

* Tue Aug 05 2008 Götz Waschk <waschk@mandriva.org> 2.13.6-1mdv2009.0
+ Revision: 264069
- new version
- drop patches 23,24

* Thu Jul 31 2008 Frederic Crozat <fcrozat@mandriva.com> 2.13.5-3mdv2009.0
+ Revision: 258057
- Patch24 (SVN): fix crash in gtk print dialog (GNOME bug #544390)

* Tue Jul 22 2008 Frederic Crozat <fcrozat@mandriva.com> 2.13.5-2mdv2009.0
+ Revision: 240404
- Force xinerama build (configure flag can be removed with next gtk release, fixed in upstream svn)
- Patch23: fix xinerama when randr 1.2 is in compat mode (GNOME bug #543317) (Mdv bug #42067)

* Tue Jul 22 2008 Götz Waschk <waschk@mandriva.org> 2.13.5-1mdv2009.0
+ Revision: 240110
- new version
- bump glib dep

* Thu Jul 17 2008 Frederic Crozat <fcrozat@mandriva.com> 2.13.4-2mdv2009.0
+ Revision: 237745
- Update minimal versions for glib/atk/pango/cairo (fix upgrade)
- Fix build on 2008.1

* Sun Jul 06 2008 Götz Waschk <waschk@mandriva.org> 2.13.4-1mdv2009.0
+ Revision: 232164
- new version

* Thu Jul 03 2008 Götz Waschk <waschk@mandriva.org> 2.13.3-1mdv2009.0
+ Revision: 230986
- fix buildrequires
- new version
- add gail libs
- rediff patch 4
- drop patches 27,28
- disable --no-undefined

* Tue Jul 01 2008 Götz Waschk <waschk@mandriva.org> 2.12.11-1mdv2009.0
+ Revision: 230550
- new version
- drop patch 29

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon Jun 09 2008 Frederic Crozat <fcrozat@mandriva.com> 2.12.10-2mdv2009.0
+ Revision: 217094
- Patch29 (SVN): fix menu positioning regression (GNOME bug #536757)

* Thu Jun 05 2008 Frederic Crozat <fcrozat@mandriva.com> 2.12.10-1mdv2009.0
+ Revision: 215227
- Release 2.12.10
- Remove patches 24 and 29, merged upstream

* Wed Apr 02 2008 Frederic Crozat <fcrozat@mandriva.com> 2.12.9-2mdv2008.1
+ Revision: 191596
- Patch29: fix crash in cups backend on 64bits (Mdv bug #39711)

* Wed Mar 12 2008 Götz Waschk <waschk@mandriva.org> 2.12.9-1mdv2008.1
+ Revision: 187040
- new version
- drop patches 25 and 26

* Mon Mar 03 2008 Frederic Crozat <fcrozat@mandriva.com> 2.12.8-5mdv2008.1
+ Revision: 177967
- Move suggest on ia_ora-gnome engine from gtk+2.0 to lib package, ensure 32bit engine is pulled when installing 32bits lib package after 64bit package is installed (Mdv bug #38405)

* Fri Feb 29 2008 Frederic Crozat <fcrozat@mandriva.com> 2.12.8-4mdv2008.1
+ Revision: 176692
- Patch26 (SVN): fix libbeagle soname
- Patch27 (SVN): fix critical warnings from Treeview (GNOME bug #488119)
- Patch28 (SVN): add Gtk/IMModule xsetting support (GNOME bug #502446)

* Thu Feb 28 2008 Frederic Crozat <fcrozat@mandriva.com> 2.12.8-3mdv2008.1
+ Revision: 176512
- Update patch12 for new theme names : Ia Ora Smooth for Free and Ia Ora Blue for One

* Wed Feb 13 2008 Frederic Crozat <fcrozat@mandriva.com> 2.12.8-2mdv2008.1
+ Revision: 166986
- Patch25 (SVN): guard recent manager against recursion (GNOME bug #507605) (SVN)

* Wed Feb 13 2008 Götz Waschk <waschk@mandriva.org> 2.12.8-1mdv2008.1
+ Revision: 166940
- new version

* Wed Jan 30 2008 Götz Waschk <waschk@mandriva.org> 2.12.7-1mdv2008.1
+ Revision: 160153
- new version

* Tue Jan 29 2008 Götz Waschk <waschk@mandriva.org> 2.12.6-1mdv2008.1
+ Revision: 159675
- new version

* Sun Jan 13 2008 Funda Wang <fwang@mandriva.org> 2.12.5-2mdv2008.1
+ Revision: 150846
- rebuild against latest gnutls

* Wed Jan 09 2008 Götz Waschk <waschk@mandriva.org> 2.12.5-1mdv2008.1
+ Revision: 147105
- new version

* Tue Jan 08 2008 Götz Waschk <waschk@mandriva.org> 2.12.4-1mdv2008.1
+ Revision: 146645
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Dec 18 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.3-2mdv2008.1
+ Revision: 132239
- Only apply patch22 when building on 2008.0 or earlier

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Dec 05 2007 Götz Waschk <waschk@mandriva.org> 2.12.3-1mdv2008.1
+ Revision: 115637
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - buildrequires X11-devel instead of XFree86-devel

* Tue Nov 27 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.2-1mdv2008.1
+ Revision: 113370
- Regenerate patch22 by removing useless patching in it

  + Götz Waschk <waschk@mandriva.org>
    - new version
    - drop patches 29,30

* Mon Nov 12 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.1-3mdv2008.1
+ Revision: 108171
- Update patch29 with upstream fix

* Mon Oct 29 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.1-2mdv2008.1
+ Revision: 103005
- Patch30: various SVN fixes (GNOME bugs #491207, #488051,#479463, #468793, #486420, #488918)

* Sat Oct 27 2007 Götz Waschk <waschk@mandriva.org> 2.12.1-1mdv2008.1
+ Revision: 102555
- update patch 22
- new version
- drop patches 23,25,26,27,28

* Wed Oct 10 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.0-8mdv2008.1
+ Revision: 96748
- Patch29 (Kris): fix gdkwindow invalidation crash (Firefox print preview crash) (Mdv bug #33579)

* Thu Oct 04 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.0-7mdv2008.0
+ Revision: 95322
- Patch27 (SVN): improve file chooser entry field response to Ctrl-L shortcut (GNOME bug #455284)
- Patch28 (SVN): fix filechooser date conversion for non-UTF8 locale (GNOME bug #482504)

* Wed Sep 26 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.0-6mdv2008.0
+ Revision: 93052
- Patch26 (SVN): fix crash when cancelling search (GNOME bug #480123)

* Mon Sep 24 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.0-5mdv2008.0
+ Revision: 92493
- Patch25: prevent crash with old eclipse release (GNOME bug #460194)

* Mon Sep 24 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.0-4mdv2008.0
+ Revision: 92484
- Patch23 : various fixes from SVN
- Remove patch21 (merged in patch23)
- Patch24: fix XDG mime cache crash (fd.o bug #12512)

* Sun Sep 16 2007 Götz Waschk <waschk@mandriva.org> 2.12.0-3mdv2008.0
+ Revision: 88522
- readd patch 22 (bug #33003)

* Fri Sep 14 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.0-2mdv2008.0
+ Revision: 85679
- Update patch12 with theme Ia Ora One for desktop metaclass

* Fri Sep 14 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.0-1mdv2008.0
+ Revision: 85497
- Patch21 (SVN): fix icon cache validation (GNOME bug #476342)

  + Götz Waschk <waschk@mandriva.org>
    - new version
    - drop merged patches 17,18,19,21,22

* Tue Sep 11 2007 Götz Waschk <waschk@mandriva.org> 2.11.6-7mdv2008.0
+ Revision: 84539
- fix context menu (upstream bug #449371)

* Mon Sep 03 2007 Frederic Crozat <fcrozat@mandriva.com> 2.11.6-6mdv2008.0
+ Revision: 78683
- Patch19 (Jan de Groot): prevent Flash to crash with glib 2.12 (GNOME bug #463773)
- Patch20 (MK): rename Uzbek translations to match mdv-2008.0 locales-uz (Mdv bug #33003)

* Thu Aug 30 2007 Frederic Crozat <fcrozat@mandriva.com> 2.11.6-5mdv2008.0
+ Revision: 75709
- Patch19 (SVN): fix build with latest CUPS
- move im-multipress.conf file from lib to main package

* Wed Aug 08 2007 Frederic Crozat <fcrozat@mandriva.com> 2.11.6-4mdv2008.0
+ Revision: 60352
- Patch18 (SVN): fix crash on deprecated tooltip private field access (Mdv bug #32034)

* Wed Aug 08 2007 Frederic Crozat <fcrozat@mandriva.com> 2.11.6-3mdv2008.0
+ Revision: 60090
- Add xdg-user-dirs-gtk as suggest
- Use suggests instead of hard dependencies for ia-ora
- add bootstrap mode for those suggests
- Drop patch16, it won't be revived

* Tue Jul 31 2007 Frederic Crozat <fcrozat@mandriva.com> 2.11.6-2mdv2008.0
+ Revision: 57080
- Patch17 (SVN): fix tooltip on systray

* Sat Jul 21 2007 Götz Waschk <waschk@mandriva.org> 2.11.6-1mdv2008.0
+ Revision: 54261
- new version

* Tue Jul 03 2007 Götz Waschk <waschk@mandriva.org> 2.11.5-1mdv2008.0
+ Revision: 47384
- new version
- update file list

* Wed Jun 20 2007 Götz Waschk <waschk@mandriva.org> 2.11.4-1mdv2008.0
+ Revision: 41806
- new version
- drop patch 0
- disable patch 16

* Mon Jun 18 2007 Götz Waschk <waschk@mandriva.org> 2.11.3-2mdv2008.0
+ Revision: 40743
- fix clash with C++ symbol

* Sun Jun 17 2007 Götz Waschk <waschk@mandriva.org> 2.11.3-1mdv2008.0
+ Revision: 40593
- disable checks, they fail in iurt
- fix buildrequires
- new version

* Wed Jun 06 2007 Götz Waschk <waschk@mandriva.org> 2.11.2-1mdv2008.0
+ Revision: 36051
- new version
- new version
- drop patches 15,17
- rediff patch 16
- bump deps

* Thu May 03 2007 Götz Waschk <waschk@mandriva.org> 2.10.12-1mdv2008.0
+ Revision: 21346
- new version
- update patch 17
- drop patch 18


* Fri Mar 16 2007 Frederic Crozat <fcrozat@mandriva.com> 2.10.11-2mdv2007.1
+ Revision: 145284
- Patch18(SVN): fix invalid read in icon cache reload and size of filechooser

  + Thierry Vignaud <tvignaud@mandriva.com>
    - INSTALL is useless for end users; better package NEWS instead

* Wed Mar 14 2007 Götz Waschk <waschk@mandriva.org> 2.10.11-1mdv2007.1
+ Revision: 143332
- new version

* Mon Mar 12 2007 Götz Waschk <waschk@mandriva.org> 2.10.10-1mdv2007.1
+ Revision: 142065
- new version
- drop patch 18

* Wed Mar 07 2007 Frederic Crozat <fcrozat@mandriva.com> 2.10.9-6mdv2007.1
+ Revision: 134744
-Patch18 (SVN): various bug fixes from SVN

* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 2.10.9-5mdv2007.1
+ Revision: 122242
- trying to fix buildrequires for pkgconfig#

* Sat Feb 17 2007 Götz Waschk <waschk@mandriva.org> 2.10.9-4mdv2007.1
+ Revision: 122139
- trying to fix buildrequires for pkgconfig#

* Sat Feb 17 2007 Götz Waschk <waschk@mandriva.org> 2.10.9-3mdv2007.1
+ Revision: 122120
- rebuild for pkgconfig deps

* Thu Feb 08 2007 Frederic Crozat <fcrozat@mandriva.com> 2.10.9-2mdv2007.1
+ Revision: 117732
- Update patch17 with new version from Fedora

* Mon Jan 22 2007 Götz Waschk <waschk@mandriva.org> 2.10.9-1mdv2007.1
+ Revision: 112027
- new version
- drop patch 0

* Sun Jan 21 2007 Götz Waschk <waschk@mandriva.org> 2.10.8-2mdv2007.1
+ Revision: 111289
- fix a wrong free, trying to solve bug #28319

* Wed Jan 17 2007 Götz Waschk <waschk@mandriva.org> 2.10.8-1mdv2007.1
+ Revision: 109732
- new version
- rediff patch 17

* Sat Jan 06 2007 Götz Waschk <waschk@mandriva.org> 2.10.7-1mdv2007.1
+ Revision: 104759
- new version
- drop patches 0,14
- rediff patches 4,15,17

* Tue Dec 12 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.10.6-5mdv2007.1
+ Revision: 95936
- 2.10.6-5mdv
- fix build on ppc64

* Mon Nov 27 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.6-4mdv2007.1
+ Revision: 87591
- Fix buildrequires
- Disable building in separate builddir, it breaks debug packages
- Patch14: fix icon crash (Mdv bug #27013)
- Patch15: stop cursor blinking after some time (Fedora) (CVS)
- Patch16: add fam monitoring for recent files (Fedora)
- Patch17: add search file in file selector (Fedora)

* Fri Oct 13 2006 Götz Waschk <waschk@mandriva.org> 2.10.6-3mdv2007.1
+ Revision: 63821
- work around problem at check stage
- unpack patches
- Import gtk+2.0

* Fri Oct 06 2006 Gtz Waschk <waschk@mandriva.org> 2.10.6-1mdv2007.0
- fix test
- New version 2.10.6

* Wed Oct 04 2006 Gtz Waschk <waschk@mandriva.org> 2.10.5-1mdv2007.0
- new version

* Sun Sep 24 2006 Gtz Waschk <waschk@mandriva.org> 2.10.4-1mdv2007.0
- drop patch 14
- New version 2.10.4

* Fri Sep 22 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.3-4mdv2007.0
- Add missing buildrequires on cups-devel, fix missing printers on x86-64
- Add explicit requires on libia-ora_gnome to prevent 32bit engine missing
  on 64 bits system

* Wed Sep 13 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.3-3mdv2007.0
- Patch14 (CVS): various cvs fixes, including for Mdv bug #25570

* Sat Sep 09 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.3-2mdv2007.0
- don't show error if /usr/share/icons doesn't exist
- requires ia_ora-gnome (ugly but needed for upgrade)
- move gtk-input-query-method call to libname post

* Wed Sep 06 2006 Gtz Waschk <waschk@mandriva.org> 2.10.3-1mdv2007.0
- drop patch 14
- New version 2.10.3

* Tue Sep 05 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.2-3mdv2007.0
- Patch14 (CVS): fix symbolic color parsing with some locales

* Wed Aug 30 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.2-2mdv2007.0
- Update patch12 for orange theme

* Sat Aug 19 2006 Götz Waschk <waschk@mandriva.org> 2.10.2-1mdv2007.0
- New release 2.10.2

* Fri Aug 11 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.1-1mdv2007.0
- update patch12 for Ia Ora theme

* Tue Jul 25 2006 Gtz Waschk <waschk@mandriva.org> 2.10.1-1mdv2007.0
- drop patch 14
- New release 2.10.1

* Fri Jul 07 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.0-2mdv2007.0
- Patch14 (CVS): fix symbolic colors with engines (Mdv bug #346668)

* Tue Jul 04 2006 Gtz Waschk <waschk@mandriva.org> 2.10.0-1mdv2007.0
- bump deps
- drop patch 10
- New release 2.10.0

* Fri Jun 23 2006 Götz Waschk <waschk@mandriva.org> 2.9.4-1
- New release 2.9.4

* Tue Jun 20 2006 Frederic Crozat <fcrozat@mandriva.com> 2.9.3-2mdv2007.0
- Update glib version dependency

* Wed Jun 14 2006 Gtz Waschk <waschk@mandriva.org> 2.9.3-1mdv2007.0
- bump deps
- drop patch 14
- New release 2.9.3

* Sat Jun 10 2006 Frederic Crozat <fcrozat@mandriva.com> 2.9.2-3mdv2007.0
- Patch14 (CVS): fix button label regression

* Thu Jun 08 2006 Frederic Crozat <fcrozat@mandriva.com> 2.9.2-2mdv2007.0
- Fix missing stock_icon

* Wed Jun 07 2006 Götz Waschk <waschk@mandriva.org> 2.9.2-1
- New release 2.9.2

* Fri Jun 02 2006 Gtz Waschk <waschk@mandriva.org> 2.9.1-2mdv2007.0
- reenable checks

* Thu Jun 01 2006 Frederic Crozat <fcrozat@mandriva.com> 2.9.1-1mdv2007.0
- Release 2.9.1

* Tue May 30 2006 Gtz Waschk <waschk@mandriva.org> 2.8.18-2mdv2007.0
- fix buildrequires

* Mon May 29 2006 Gtz Waschk <waschk@mandriva.org> 2.8.18-1mdv2007.0
- disable check, Xvfb doesn't work
- drop patch 14
- New release 2.8.18

* Thu May 18 2006 Frederic Crozat <fcrozat@mandriva.com> 2.8.17-4mdk
- Fix build with modular xorg

* Sat May 13 2006 Frederic Crozat <fcrozat@mandriva.com> 2.8.17-3mdk
- Drop explicit requires on XFree86-devel (Mdk bug #22057)

* Sat Apr 29 2006 Frederic Crozat <fcrozat@mandriva.com> 2.8.17-2mdk
- Patch14 (CVS): fix shifted text (GNOME bug #334582)

* Sun Apr 09 2006 Götz Waschk <waschk@mandriva.org> 2.8.17-1mdk
- New release 2.8.17

* Wed Mar 15 2006 Frederic Crozat <fcrozat@mandriva.com> 2.8.16-1mdk
- Release 2.8.16

* Mon Mar 13 2006 Gtz Waschk <waschk@mandriva.org> 2.8.15-1mdk
- run the checks with Xvfb
- New release 2.8.15

* Wed Mar 08 2006 Frederic Crozat <fcrozat@mandriva.com> 2.8.14-1mdk
- Release 2.8.14

* Sat Feb 25 2006 Götz Waschk <waschk@mandriva.org> 2.8.13-1mdk
- New release 2.8.13

* Mon Feb 13 2006 Gtz Waschk <waschk@mandriva.org> 2.8.12-1mdk
- fix .la perms
- New release 2.8.12

* Mon Jan 30 2006 Gtz Waschk <waschk@mandriva.org> 2.8.11-1mdk
- drop patch 15
- New release 2.8.11

* Thu Jan 12 2006 Thierry Vignaud <tvignaud@mandriva.com> 2.8.10-3mdk
- fix requires

* Thu Jan 12 2006 Thierry Vignaud <tvignaud@mandriva.com> 2.8.10-2mdk
- fix requires

* Thu Jan 12 2006 Götz Waschk <waschk@mandriva.org> 2.8.10-1mdk
- New release 2.8.10

* Sun Dec 11 2005 Gtz Waschk <waschk@mandriva.org> 2.8.9-1mdk
- drop merged patch 16
- New release 2.8.9
- use mkrel

* Mon Dec 05 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.8-2mdk
- Patch16 (CVS): various fixes for filechooser

* Tue Nov 29 2005 Götz Waschk <waschk@mandriva.org> 2.8.8-1mdk
- New release 2.8.8

* Wed Nov 16 2005 Götz Waschk <waschk@mandriva.org> 2.8.7-1mdk
- New release 2.8.7

* Wed Oct 12 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.6-2mdk
- Rebuild to get debug package

* Wed Oct 05 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.6-1mdk
- Release 2.8.6
- Remove patches 16 & 17 (merged upstream)
- Update patch4 (Gotz)

* Tue Sep 06 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.3-4mdk 
- Patch17 (CVS): various fixes

* Sat Sep 03 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.3-3mdk 
- Patch16 (CVS): fix crash in gtk fileselector

* Thu Sep 01 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.8.3-2mdk
- re-add patch15: still required

* Wed Aug 31 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.3-1mdk 
- Release 2.8.3
- Remove patch14 (merged upstream)

* Fri Aug 26 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.2-2mdk 
- Patch14 : fix crash in gdk screen

* Thu Aug 25 2005 Gtz Waschk <waschk@mandriva.org> 2.8.2-1mdk
- drop merged patch 14
- New release 2.8.2

* Thu Aug 25 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.1-2mdk 
- Patch14 (CVS): fix default dpi and crash in theme thumbnaiL

* Thu Aug 25 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.1-1mdk 
- New release 2.8.1
- Remove patches 14 and 15 (merged upstream)

* Fri Aug 19 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.8.0-2mdk
- Patch15: fix abi check scripts for ppc

* Wed Aug 17 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.0-1mdk 
- Release 2.8.0
- Regenerate patch12
- Remove patch14 (merged upstream)
- Patch14 (CVS): various bugfixes from CVS
- Update icon cache at post

* Fri Aug 12 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.9-3mdk 
- Patch14 (CVS): fix treeview refresh

* Sat Aug 06 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.9-2mdk 
- No longer disable gcse in gcc

* Wed Aug 03 2005 Gtz Waschk <waschk@mandriva.org> 2.6.9-1mdk
- update patch 5
- rpmbuildupdate fix
- New release 2.6.9

* Fri Jun 17 2005 Gtz Waschk <waschk@mandriva.org> 2.6.8-1mdk
- replace prereq by current syntax
- drop merged patches 14,15
- new version

* Sat Apr 30 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.6.7-3mdk
- patch 15: fix RTL bug with TreeViews (#12846)

* Sat Apr 30 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.7-2mdk 
- Patch14: remove debug output in bmp loader

* Tue Apr 19 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.7-1mdk
- Release 2.6.7
- Remove patches 14 & 15 (merged upstream)

* Fri Apr 08 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.4-2mdk 
- Patch14 (CVS): fix BMP vulnerability (CAN-2005-0891)
- Patch15 (CVS): fix various crashes

* Wed Mar 02 2005 Gtz Waschk <waschk@linux-mandrake.com> 2.6.4-1mdk
- new version

* Mon Feb 28 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.3-1mdk 
- Release 2.6.3

* Fri Feb 04 2005 Gtz Waschk <waschk@linux-mandrake.com> 2.6.2-1mdk
- drop patches 14,15
- new version

* Fri Feb 04 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.1-4mdk 
- Update patch14 to fix all cases (pixel)

* Fri Jan 21 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.1-3mdk 
- Patch15 (CVS): various fixes from CVS, including one for Mdk bug #12898

* Mon Jan 17 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.1-2mdk 
- Patch14 (CVS): fix default direction when keymap is neutral

* Sun Jan 09 2005 Gtz Waschk <waschk@linux-mandrake.com> 2.6.1-1mdk
- drop merged patch 14
- new version

* Mon Dec 20 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.0-3mdk 
- Patch14 (CVS): fix filechooser hang with threaded apps

* Fri Dec 17 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.0-2mdk 
- Fix conflicts

* Fri Dec 17 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.0-1mdk
- Release 2.6.0
- Regenerate patches 4, 10
- Remove patches 15, 16, 17, 18 (merged upstream)

* Fri Dec 03 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.14-1mdk
- Release 2.4.14
- Regenerate patch17
- Remove patches 19, 20 (merged upstream)

* Wed Nov 17 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.13-2mdk
- Update patch15 with crash fix from fedora
- Patch20 (CVS): speed enhancement in GtkUIManager and signal handling

* Tue Oct 19 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.13-1mdk
- Release 2.4.13
- Remove patches 14, 17, 18, 19, 20 (merged upstream)
- Regenerate patch16 (partially merged), fix '/' shortcut with french keyboard
- Patch17 (Fedora): XSync based update counter
- Patch18 (Fedora): backport support for PangoLogAttr.backspace_deletes_character
- Patch19 (Fedora): fix pa translation

* Tue Oct 05 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-9mdk
- Update patch14 with more cvs fixes

* Sat Oct 02 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-8mdk
- Patch17 (Fedora + me): improve completion popup speed for large directories
- Patch18 (Fedora): bigger arrows for path bar
- Patch19 (Fedora): improve folder selection in file chooser
- Patch20: always set cell renderer data (Mdk bug #11610)

* Fri Sep 24 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-7mdk
- Run automake for patch4

* Tue Sep 21 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-6mdk
- add prereq on latest libtiff release because ABI got broken (Mdk bug #11607)
- update patch14 with more cvs fixes (GNOME bugs 143486, #143868, 
  - Patch15 (Fedora): add typeahead for treeview
- Patch16 (Fedora): get location popup search when start typing  with /

* Sat Sep 18 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-5mdk
- Update patch14 with security fixes for ico, bmp and xpm loading, as
  well as check for valid utf8 in UTF-8 string selection

* Wed Sep 15 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-4mdk
- Update patch14 with fix for GNOME bug #152333

* Thu Sep 09 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-3mdk
- Update patch14 with fixes for GNOME bugs #151963, #151985 & #151752

* Thu Sep 02 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-2mdk
- Patch14 (CVS): various bug fixes from CVS (#151542, 151490, 131226)

* Fri Aug 27 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.9-1mdk
- Release 2.4.9
- Remove patch14 (merged upstream)

* Thu Aug 19 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.7-2mdk
- Patch14: fix regression in pixops scaling
- disable gcc gcse, it causes wrong painting of south arrow

* Tue Aug 17 2004 Gtz Waschk <waschk@linux-mandrake.com> 2.4.7-1mdk
- disable fb build again
- drop merged patch 11
- new version

* Thu Jul 29 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.4.4-5mdk
- fix wrapper script to handle extra dir as first parameter

* Thu Jul 22 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.4.4-4mdk
- remove rpath hack so it builds without gdk-pixbuf-devel installed

* Tue Jul 20 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.4-3mdk
- Move gtk-query-immodules and gdk-pixbuf-query script to lib package
 (to be biarch friendly) (gb)

* Tue Jul 20 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.4-2mdk
- biarch support (gb)
- Change dependency order

* Sun Jul 11 2004 Gtz Waschk <waschk@linux-mandrake.com> 2.4.4-1mdk
- fix freetype build
- reenable fb build
- New release 2.4.4

* Sat Jun 12 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.3-1mdk
- Release 2.4.3

* Mon Jun 07 2004 Gtz Waschk <waschk@linux-mandrake.com> 2.4.2-1mdk
- disable fb (didn't build)
- reenable libtoolize
- New release 2.4.2

* Fri May 07 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.1-2mdk
- Update patch12 to use gnome icon theme when available (Mdk bug #9688)

* Sat May 01 2004 Gtz Waschk <waschk@linux-mandrake.com> 2.4.1-1mdk
- new version

* Sat May 01 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.0-2mdk
- Patch12 : use Galaxy theme by default if available

* Sat Apr 03 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.0-1mdk
- Release 2.4.0 (from Gotz)
- binary version 2.4
- requires new glib and new pango
- Remove patches patches 6, 8, 12, 14, 15, 16 17 (merged), 
  11, 16 (no longer neeed) 
- buildrequire automake1.7
- Patch11 : fix linuxfb build

